@@ -1,6 +1,6 @@
 """Hypha Artifact fsspec interface."""
 
 from .hypha_artifact import HyphaArtifact
-from .async_hypha_artifact import AsyncHyphaArtifact
+from .async_hypha_artifact_compat import AsyncHyphaArtifact
 
 __all__ = ["HyphaArtifact", "AsyncHyphaArtifact"]
